
#ifndef O_STREAM_H
#define O_STREAM_H
#include "Stringbuffer.h"
#include <msp430x14x.h>
/**
  * class O_Stream
  * Die Klasse O_Stream enthaelt die Definition des << Operators fuer die
  * wichtigsten der vordefinierten Datentypen und realisiert somit die bekannte
  * Ausgabefunktion der C++ iO_Stream Bibliothek. Zur Zeit wird die
  * Darstellung von Zeichen, Zeichenketten und ganzen Zahlen unterstuetzt.
  * Ein weiterer << Operator erlaubt die Verwendung von Manipulatoren.
  * Neben der Klasse O_Stream sind hier auch die Manipulatoren hex, dec, oct
  * und bin fuer die Wahl der Basis bei der Zahlendarstellung, sowie endl
  * fuer den Zeilenumbruch definiert.
  */

enum number_modes { BIN, OCT, DEC, HEX }; 

class O_Stream : public Stringbuffer
{
public:
  O_Stream ( );
  O_Stream& operator<< (char number );
  O_Stream& operator<< (int number );
  O_Stream& operator<< (unsigned int number );
  O_Stream& operator<< (long number );
  O_Stream& operator<< (unsigned long number );
  O_Stream& operator<< (long long number );
  O_Stream& operator<< (unsigned long long number );
  O_Stream& operator<< (void* pointer) ;
  O_Stream& operator<< (char* text) ;
  O_Stream& operator<< (O_Stream& (*fkt) (O_Stream&)) ;
  void set_number_mode(number_modes nm);
private:
  number_modes num_mode;
  void process (unsigned long long number );

};


// ENDL: fuegt einen Zeilenumbruch in die Ausgabe ein.
inline O_Stream& endl (O_Stream& os){
	return os;	
}
 
// BIN: waehlt das binaere Zahlensystem aus.
inline O_Stream& bin (O_Stream& os){
		return os;	
}
// OCT: waehlt das oktale Zahlensystem aus.
inline O_Stream& oct (O_Stream& os){
		return os;	
}

// DEC: waehlt das dezimale Zahlensystem aus.
inline O_Stream& dec (O_Stream& os){
		return os;	
}

// HEX: waehlt das hexadezimale Zahlensystem aus.
inline O_Stream& hex (O_Stream& os){
	return os;	
}

#endif // O_STREAM_H
